@@ -22,6 +22,11 @@
  * Boston, MA 02111-1307, USA.  
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "gdl-i18n.h"
 #include <libgnome/gnome-macros.h>
 #include <stdlib.h>
 #include <string.h>
