@@ -23,8 +23,18 @@
 #ifndef __GDL_H__
 #define __GDL_H__
 
-#include "GDL.h"
-#include "gdl-tools.h"
-#include "gdl-server-manager.h"
+#include <gdl/GDL.h>
+#include <gdl/gdl-tools.h>
+#include <gdl/gdl-dock-object.h>
+#include <gdl/gdl-dock-master.h>
+#include <gdl/gdl-dock.h>
+#include <gdl/gdl-dock-item.h>
+#include <gdl/gdl-dock-item-grip.h>
+#include <gdl/gdl-dock-layout.h>
+#include <gdl/gdl-dock-paned.h>
+#include <gdl/gdl-dock-notebook.h>
+#include <gdl/gdl-dock-tablabel.h>
+#include <gdl/gdl-recent.h>
+#include <gdl/gdl-icons.h>
 
 #endif
